Liangent has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/109459


Change subject: Fix various comments from 84a2f570.
......................................................................

Fix various comments from 84a2f570.

Change-Id: I03f7778bc93a255475aa132a09c6da15decd1549
---
M includes/Collation.php
M includes/utils/ArrayUtils.php
2 files changed, 14 insertions(+), 8 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/59/109459/1

diff --git a/includes/utils/ArrayUtils.php b/includes/utils/ArrayUtils.php
index 802cdbc..037663c 100644
--- a/includes/utils/ArrayUtils.php
+++ b/includes/utils/ArrayUtils.php
@@ -22,6 +22,8 @@
 
 /**
  * A collection of static methods to play with arrays.
+ *
+ * @since 1.21
  */
 class ArrayUtils {
        /**
@@ -94,13 +96,15 @@
         * Do a binary search, and return the index of the largest item that 
sorts
         * less than or equal to the target value.
         *
+        * @since 1.23
+        *
         * @param array $valueCallback A function to call to get the value with
         *     a given array index.
-        * @param $valueCount int The number of items accessible via 
$valueCallback,
+        * @param int $valueCount The number of items accessible via 
$valueCallback,
         *     indexed from 0 to $valueCount - 1
-        * @param $comparisonCallback array A callback to compare two values, 
returning
+        * @param array $comparisonCallback A callback to compare two values, 
returning
         *     -1, 0 or 1 in the style of strcmp().
-        * @param $target string The target value to find.
+        * @param string $target The target value to find.
         *
         * @return int|bool The item index of the lower bound, or false if the 
target value
         *     sorts before all items.
@@ -142,9 +146,11 @@
         *
         * Note: empty arrays are removed.
         *
-        * @param $array1 array The array to compare from
-        * @param $array2 array An array to compare against
-        * @param ... array More arrays to compare against
+        * @since 1.23
+        *
+        * @param array $array1 The array to compare from
+        * @param array $array2 An array to compare against
+        * @param array ... More arrays to compare against
         * @return array An array containing all the values from array1
         *               that are not present in any of the other arrays.
         */

diff --git a/includes/Collation.php b/includes/Collation.php
index b51256b..d2a5797 100644
--- a/includes/Collation.php
+++ b/includes/Collation.php
@@ -514,7 +514,7 @@
         * Do a binary search, and return the index of the largest item that 
sorts
         * less than or equal to the target value.
         *
         * @deprecated in 1.22; use ArrayUtils::findLowerBound() instead
         *
         * @param array $valueCallback A function to call to get the value with
         *     a given array index.
@@ -528,7 +528,7 @@
         *     sorts before all items.
         */
        function findLowerBound( $valueCallback, $valueCount, 
$comparisonCallback, $target ) {
-               wfDeprecated( __METHOD__, '1.22' );
+               wfDeprecated( __METHOD__, '1.23' );
                return ArrayUtils::findLowerBound( $valueCallback, $valueCount, 
$comparisonCallback, $target );
        }
@@ -514,7 +514,7 @@
         * less than or equal to the target value.
         *
-        * @deprecated in 1.22; use ArrayUtils::findLowerBound() instead
+        * @deprecated in 1.23; use ArrayUtils::findLowerBound() instead
         *
         * @param array $valueCallback A function to call to get the value with
 
-- 
To view, visit https://gerrit.wikimedia.org/r/109459
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I03f7778bc93a255475aa132a09c6da15decd1549
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Liangent <liang...@gmail.com>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to